PrimaryKeyField class final

Inheritance

Properties

autoIncrement bool
final
columnName String
Column name in the database
finalinherited
dartName Symbol
dart name for property on Entity class
finalinherited
hashCode int
The hash code for this object.
no setterinherited
isPrimaryKey bool
no setteroverride
nullable bool
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
type Type
Dart primitive type
finalinherited
unique bool
finalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited